..
  class.rst

ardt.datasets.AERTrialFilter
============================

.. currentmodule:: ardt.datasets

.. autoclass:: AERTrialFilter
    :members:
    :show-inheritance:
    :inherited-members:
